% set Matlab path and TOOLBOX_PATH environment variable
addpath(fullfile(pwd, 'matlab'));
setenv('BART_TOOLBOX_PATH', pwd);
